<?php

namespace Responso;

/**
 * Class Plugin. Register Responso
 *
 * @package Responso
 * */
class Plugin extends Responso_Connect {

	/**
	 * Plugin info
	 * Contains names, desription, version, paths, etc.
	 *
	 * @var object $plugin_info
	 */
	private $plugin_info;



	/**
	 * Plugin init
	 *
	 * @param  object $plugin_info .
	 * @return void
	 */
	public function __construct($plugin_info) {

		// Plugin info object
		$this->plugin_info = $plugin_info;

		// Load plugin textdomain for translations
		$this->text_domain();

		// iframes and counters URLs
		$this->responso_inbox_iframe_url = 'https://app.responso.com/extensions/woocommerce?section=index';
		$this->responso_order_iframe_url = 'https://app.responso.com/extensions/woocommerce';
		$this->responso_tickets_counters_url = 'https://app.responso.com/extensions/woocommerce/tickets/count';

		// Frontend assets
        add_action('wp_enqueue_scripts', [$this, 'frontend_assets']);

		// Admin assets
		add_action('admin_enqueue_scripts', [$this, 'admin_assets']);

        // Plugins list action link to settings
        add_filter('plugin_action_links_'.$plugin_info->basename, [$this, 'responso_settings_link']);

		// Plugin add settings page to admin menu
		add_action('admin_menu', [$this, 'responso_register_plugin_pages']);

		// Display responso meta box in single order
		add_action('add_meta_boxes', [$this, 'add_shop_order_responso_box']);

		// Add all plugin front-end forms.
		new Responso_Forms($plugin_info);

		// Ajax sending controllers
		new Responso_Ajax();
	}


	/**
	 * Load Plugin text Domain
	 */
	public function text_domain() {

		load_plugin_textdomain($this->plugin_info->text_domain, false, $this->plugin_info->domain_path);
	}


    /**
     * Enqueue frontend assets
     */
    public function frontend_assets() {

        wp_enqueue_style('responso', $this->plugin_info->plugin_url . 'assets/css/responso.css', [], $this->plugin_info->version);
		wp_enqueue_script('responso', $this->plugin_info->plugin_url . 'assets/js/responso.js', ['jquery'], '1.0.0', TRUE);
    }


	/**
	 * Enqueue admin assets
	 */
    public function admin_assets() {
		
		if(is_admin()) {
			wp_enqueue_style('responso_adm', $this->plugin_info->plugin_url . 'assets/css/responso_admin.css', [], $this->plugin_info->version);
			wp_enqueue_script('responso_adm', $this->plugin_info->plugin_url . 'assets/js/responso_admin.js', array('jquery'), '1.0.0', TRUE);
		}
    }


	/**
	 * Register admin menu settings page
	 */
	public function responso_register_plugin_pages() {

		add_menu_page(__('Inbox', 'responso'), __('Responso', 'responso'), 'administrator', 'responso', [$this, 'responso_inbox_page'], plugins_url('assets/images/icon.png', dirname(__FILE__)));
		add_submenu_page('responso', __('Responso settings', 'responso'),  __('Settings', 'responso'), 'administrator', 'responso-inbox', [$this, 'responso_settings_page']);
		add_action('admin_init', [$this, 'register_responso_settings']);
	}


	public function register_responso_settings() {

		register_setting('responso-settings', 'api_key');
		register_setting('responso-settings', 'form_shortcode', ['default'=>'[responso_contact_form]']);
		register_setting('responso-settings', 'form_header', ['default'=>'']);
		register_setting('responso-settings', 'form_text', ['default'=>'']);
		register_setting('responso-settings', 'form_subjects');
		register_setting('responso-settings', 'form_acceptance_text');
		register_setting('responso-settings', 'product_form_button_text', ['default'=>__('Ask for product', 'responso')]);
		register_setting('responso-settings', 'product_form_text');
	}
	

	public function responso_settings_page() {
		
		echo '<div class="wrap">
		<h1>'.__('Responso settings', 'responso').'</h1>
		<form method="post" action="options.php">';
			settings_fields('responso-settings');
			echo '<table class="form-table" role="presentation">
				<tr>
					<th><h2>'.__('API settings', 'responso').'</h2></th>
				</tr>
				<tr>
					<th scope="row"><label for="api_key">'.__('API key', 'responso').'</label></th>
					<td><input type="text" name="api_key" id="api_key" class="wp_admin_longer_input" placeholder="org_xxxxxxxxxxxxxxxxxxxxxx" value="'.esc_attr(get_option('api_key')).'"></td>
				</tr>
				<tr>
					<th><h2>Contact form settings</h2></th>
				</tr>
				<tr>
					<th scope="row"><label for="form_shortcode">'.__('Form shortcode', 'responso').'</label></th>
					<td>
						<input type="text" name="form_shortcode" id="form_shortcode" value="'.esc_attr(get_option('form_shortcode')).'" readonly="readonly">
						<p class="description">'.__('You may insert this contact form shortcode whichever page or post you want.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th scope="row"><label for="form_header">'.__('Form header', 'responso').'</label></th>
					<td>
						<input type="text" name="form_header" id="form_header" value="'.esc_attr(get_option('form_header')).'">
						<p class="description">'.__('Leave empty if you don\'t want the header above contact form.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th scope="row"><label for="form_text">'.__('Form text', 'responso').'</label></th>
					<td>
						<textarea name="form_text" id="form_text" rows="5" cols="50">'.esc_attr(get_option('form_text')).'</textarea>
						<p class="description">'.__('Leave empty if you don\'t want the text box between the header and the contact form.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th scope="row"><label for="form_subjects">'.__('Form subjects', 'responso').'</label></th>
					<td>
						<textarea name="form_subjects" id="form_subjects" rows="5" cols="50">'.esc_attr(get_option('form_subjects')).'</textarea>
						<p class="description">'.__('One subject per line. Leave empty if you don\'t want subject select box on the contact form.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th><h2>'.__('Product form settings','responso').'</h2></th>
				</tr>
				<tr>
					<th scope="row"><label for="product_form_button_text">'.__('Product form button text *', 'responso').'</label></th>
					<td>
						<input type="text" name="product_form_button_text" id="product_form_button_text" value="'.esc_attr(get_option('product_form_button_text')).'" required>
						<p class="description">'.__('* This field is required.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th scope="row"><label for="product_form_text">'.__('Product form text', 'responso').'</label></th>
					<td>
						<textarea name="product_form_text" id="product_form_text" rows="5" cols="50">'.esc_attr(get_option('product_form_text')).'</textarea>
						<p class="description">'.__('Leave empty if you don\'t want the text box above the product question form.', 'responso').'</p>
					</td>
				</tr>
				<tr>
					<th><h2>'.__('Global form settings','responso').'</h2></th>
				</tr>
				<tr>
					<th scope="row"><label for="form_acceptance_text">'.__('Form acceptance text', 'responso').'</label></th>
					<td>
						<textarea name="form_acceptance_text" id="form_acceptance_text" rows="5" cols="50">'.esc_attr(get_option('form_acceptance_text')).'</textarea>
						<p class="description">'.__('Leave empty if you don\'t want acceptance checkbox on the both forms.', 'responso').'</p>
					</td>
				</tr>
			</table>';
		submit_button();
		echo '</form>
		</div>';
	}


	public function responso_inbox_page() {

		echo '<div class="wrap">
		<h1>'.__('Responso Inbox', 'responso').'</h1>
		<iframe src="'.$this->responso_inbox_iframe_url.'" frameborder="0" border="0" cellspacing="0" width="800" height="600" class="iframe_box"></iframe>
		</div>';
	}

	function add_shop_order_responso_box($post) {

		add_meta_box(
			'order_responso_box',
			__('Responso user tickets', 'responso'),
			[$this, 'responso_orders_box'],
			'shop_order',
			'normal',
			'core'
		);
	}

	public function responso_orders_box() {

		global $post, $woocommerce;
		$order = new \WC_Order($post->ID);

		$coutners_params_url = '?section=order_card&email='.$order->get_billing_email().'&order_id='.$order->get_id().'&phone='.$order->get_billing_phone();
		echo "<script>
		jQuery.ajax({
			url: '".$this->responso_tickets_counters_url.$coutners_params_url."',
			type: 'GET',
			xhrFields: {
			  withCredentials: true
			},
			success: function(data) {
			  jQuery('#order_responso_box h2').append('<span class=\"responso_number responso_tickets\">'+data.count+'</span> <span class=\"responso_number responso_to_answer\">'+data.to_answer+'</span>');
			  if(data.count == 0 && data.to_answer == 0)
			  	jQuery('#order_responso_box').addClass('closed');
			},
			error: function(jqXHR, textStatus, errorThrown) {
			  jQuery('#order_responso_box h2').append('<span class=\"responso_number responso_tickets\">!</span> <span class=\"responso_number responso_to_answer\">!</span>');
			  jQuery('#order_responso_box').addClass('closed');
			}
		  });
		</script>";
		
		echo '<div id="woocommerce-order-responso" class="postbox">
		<iframe src="'.$this->responso_order_iframe_url.'?section=order_card&email='.$order->get_billing_email().'&order_id='.$order->get_id().'&phone='.$order->get_billing_phone().'" frameborder="0" border="0" cellspacing="0" width="800" height="600" class="iframe_ticket_box"></iframe>
		</div>';
	}


    /**
     * Add Settings link to Responso on plugins list
     *
     * @param  array $actions Plugin actions.
     * @return array $actions Plugin actions.
     */
    public function responso_settings_link($actions) {

        $settings = array(
            '<a href="'.admin_url('admin.php?page=responso') .'">'.__('Settings', 'responso').'</a>',
        );
        $actions = array_merge($actions, $settings);
        return $actions;
    }
}