<?php
/**
 * Responso connect class.
 *
 * @package Responso
 */

namespace Responso;

class Responso_Connect {

	/**
	 * API Url
	 *
	 * @var string $api_url url for requests.
	 */
	protected $api_url;

	/**
	 * Error codes
	 *
	 * @var array $error_codes code => message.
	 */
	protected $error_codes;

	/**
	 * Init Responso connect class
	 *
	 * @param string $sandbox If is in sandbox mode for testing, accepted: yes, no.
	 */
	public function __construct() {

		$this->api_url = 'https://app.responso.com/api';
		$this->error_codes = array(
			'400' => __( 'Incorrect data. Please contact the store administrator', 'responso' ),
			'401' => __( 'Authentication error. Please contact the store administrator', 'responso' ),
			'403' => __( 'Resource not authorized. Please contact the store administrator', 'responso' ),
			'404' => __( 'URL or resource not found. Please contact the store administrator', 'responso' ),
			'409' => __( 'Asset identification conflict. Please contact the store administrator', 'responso' ),
			'503' => __( 'Service temporarily unavailable. Please try again later', 'responso' ),
		);
	}


	/**
	 * Http post using wp_remote_post
	 *
	 * @param string $method Responso method from url.
	 * @param array  $args Post body.
	 * @return array|void
	 */
	public function remote_post($method, $args) {
		$response = wp_remote_post('https://app.responso.com/api'.$method, $args);
		if (is_wp_error($response)) {
			wc_add_notice($response->get_error_message(), 'error');
		} else {
			return (array) $this->response_handler($response);
		}
	}


	/**
	 * Http request using wp_remote_request
	 *
	 * @param string $method Responso method from url.
	 * @param array  $args Post body.
	 * @return array|void
	 */
	public function remote_request($method, $args) {
		$response = wp_remote_request($this->api_url.$method, $args);
		if (is_wp_error($response)) {
			wc_add_notice($response->get_error_message(), 'error');
		} else {
			return (array) $this->response_handler($response);
		}
	}


	public function get_curl_result($url) {

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$result = json_decode(curl_exec($ch));
		if (curl_errno($ch)) {$result = curl_error($ch);}
		curl_close($ch);

		return $result;
	}


	/**
	 * Response handler
	 *
	 * @param array $response Remote post response.
	 * @return array|void
	 */
	public function response_handler( $response ) {
		$code = wp_remote_retrieve_response_code( $response );
		switch ( $code ) :
			case '200' || '201':
				return json_decode( wp_remote_retrieve_body( $response ), true );
			case array_key_exists( $code, $this->error_codes ):
				wc_add_notice( sprintf("<strong>{%s}</strong> {%s}", $response['response']['message'], $this->error_codes['$code'] ), 'error' );
				error_log( print_r( $response, true ) );
				break;
			default:
				error_log( print_r( $response, true ) );
		endswitch;
	}
}